#!/bin/bash

# List of packages for deployment types
edgeBasic=('sas-dmcommons' 'sas-dmtkexp' 'sas-embscoreeng' 'sas-espauth' 'sas-espbase' 'sas-espconbase' 'sas-securedom' 'sas-securestrong' 'sas-tk' 'sas-tkcas3rdclnt' 'sas-tkcmp' 'sas-tkcpp' 'sas-tkcore' 'sas-tkdq' 'sas-tkesp' 'sas-tkformats' 'sas-tkfnc' 'sas-tkiog' 'sas-tkiomml' 'sas-tkl4sas' 'sas-tklua' 'sas-tkmtrb' 'sas-tknls' 'sas-tkrabbitmq' 'sas-tksecure' 'sas-tksecuressh' 'sas-tktscore' 'sas-tktslang' 'sas-tktspem')
edgeAnalytics=('sas-espanalytics' 'sas-tkaa' 'sas-tkaacas' 'sas-tketsutil' 'sas-tkregsvm' 'sas-tkstat' 'sas-tksum' 'sas-tktimefilter' 'sas-tktmfrequtil' )
edgeAstore=('sas-tkair' 'sas-tkbasestat' 'sas-tkcmptrvsn' 'sas-tkdplrning' 'sas-tkhpdmine' 'sas-tkormpgraph' 'sas-tktxtan')
edgeGpu=('sas-nvidiacuda' 'sas-sasgpudcfg' 'sas-sasgpud')
edgeTextAnalytics=('sas-tktxtan' 'sas-txtmineng' 'sas-tkaudio')

# Repo paths
edgeRepo="./espedge_repos"
sasRepo="$edgeRepo/sas_repos"

# Entitlements
depData=SAS_Viya_deployment_data.zip
cacert=SAS_CA_Certificate.pem
cert=entitlement_certificate.pem

# Make sure files are in place
if [ ! -f mirrormgr ] ; then
  echo "Could not find mirrormgr at $PWD. Exiting"
  exit
fi
if [ ! -x mirrormgr ] ; then
  echo "mirrormgr must be set to executable. Exiting"
  exit
fi

# Loop through repo list to create mirrors for move packages
for repo in "$@"
do
  if [[ $repo == *aarch64_ubuntu_linux_16* ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform aarch64-ubuntu-linux-16 --type apt --latest --path $sasRepo
    elif [ -f $cacert ] && [ -f $cert ] ; then
      ./mirrormgr mirror --cert $cert --cacert $cacert --platform aarch64-ubuntu-linux-16 --type apt --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    for pkgsDir in $(find . -name 'sas-*arm64*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *main ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/basic ]; then
              mkdir -p ${edgeRepo}/$repo/basic
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/analytics ]; then
              mkdir -p ${edgeRepo}/$repo/analytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/astore ]; then
              mkdir -p ${edgeRepo}/$repo/astore
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/gpu ]; then
              mkdir -p ${edgeRepo}/$repo/gpu
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] && [ -f $pkgsDir/sas-txtmineng_*.deb ]; then
            if [ ! -d ${edgeRepo}/$repo/textanalytics ]; then
              mkdir -p ${edgeRepo}/$repo/textanalytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}_*.deb ] ; then
                packToRemove=$pkgsDir/${i}_*.deb
                rm $packToRemove
            fi
        done
        # move any leftover packages to upgradepkgs dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$repo/upgradepkgs" ] ; then
              mkdir -p ${edgeRepo}/$repo/upgradepkgs
            fi
            cp ${f} ${edgeRepo}/$repo/upgradepkgs
          fi
        done

      fi
    done
  fi

  if [[ $repo == *ubuntu_linux_14* ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-ubuntu-linux-14 --type apt --latest --path $sasRepo
    elif [ -f $cacert ] && [ -f $cert ] ; then
      ./mirrormgr mirror --cert $cert --cacert $cacert --platform x64-ubuntu-linux-14 --type apt --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    for pkgsDir in $(find . -name 'sas-*amd64*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *main ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/basic ]; then
              mkdir -p ${edgeRepo}/$repo/basic
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/analytics ]; then
              mkdir -p ${edgeRepo}/$repo/analytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/astore ]; then
              mkdir -p ${edgeRepo}/$repo/astore
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$repo/gpu ]; then
              mkdir -p ${edgeRepo}/$repo/gpu
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] && [ -f $pkgsDir/sas-txtmineng_*.deb ]; then
            if [ ! -d ${edgeRepo}/$repo/textanalytics ]; then
              mkdir -p ${edgeRepo}/$repo/textanalytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$repo/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}_*.deb ] ; then
                packToRemove=$pkgsDir/${i}_*.deb
                rm $packToRemove
            fi
        done

        # move any leftover packages to upgradepkgs dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$repo/upgradepkgs" ] ; then
              mkdir -p ${edgeRepo}/$repo/upgradepkgs
            fi
            cp ${f} ${edgeRepo}/$repo/upgradepkgs
          fi
        done

      fi
    done
  fi

  if [[ $repo == *suse_linux_12* ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-suse-linux-12 --type yum --latest --path $sasRepo
    elif [ -f $cacert ] && [ -f $cert ] ; then
      ./mirrormgr mirror --cert $cert --cacert $cacert --platform x64-suse-linux-12 --type yum --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    
    for pkgsDir in $(find . -name 'sas-*suse*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *suse*Packages/s ]] ; then
        chmod -R ug+rw $pkgsDir
        
        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/basic ]; then
              mkdir -p ${edgeRepo}/$repo/basic
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/analytics ]; then
              mkdir -p ${edgeRepo}/$repo/analytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/astore ]; then
              mkdir -p ${edgeRepo}/$repo/astore
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/gpu ]; then
              mkdir -p ${edgeRepo}/$repo/gpu
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] && [ -f $pkgsDir/sas-txtmineng-*.rpm ]; then
            if [ ! -d ${edgeRepo}/$repo/textanalytics ]; then
              mkdir -p ${edgeRepo}/$repo/textanalytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}-*.rpm ] ; then
                packToRemove=$pkgsDir/${i}-*.rpm
                rm $packToRemove
            fi
        done

        # move any leftover packages to upgradepkgs dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$repo/upgradepkgs" ] ; then
              mkdir -p ${edgeRepo}/$repo/upgradepkgs
            fi
            cp ${f} ${edgeRepo}/$repo/upgradepkgs
          fi
        done

      fi
    done
  fi

  if [[ $repo == *yocto_linux_1* ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-yocto-linux-1 --type yum --latest --path $sasRepo
    elif [ -f $cacert ] && [ -f $cert ] ; then
      ./mirrormgr mirror --cert $cert --cacert $cacert --platform x64-yocto-linux-1 --type yum --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi

    for pkgsDir in $(find . -name 'sas-*yocto*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *yocto*Packages/s ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ ! -d ${edgeRepo}/$repo/basic ]; then
              mkdir -p ${edgeRepo}/$repo/basic
            fi
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/analytics ]; then
              mkdir -p ${edgeRepo}/$repo/analytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/astore ]; then
              mkdir -p ${edgeRepo}/$repo/astore
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/gpu ]; then
              mkdir -p ${edgeRepo}/$repo/gpu
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/gpu
          fi
        done
       
        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] && [ -f $pkgsDir/sas-txtmineng-*.rpm ]; then
            if [ ! -d ${edgeRepo}/$repo/textanalytics ]; then
              mkdir -p ${edgeRepo}/$repo/textanalytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}-*.rpm ] ; then
                packToRemove=$pkgsDir/${i}-*.rpm
                rm $packToRemove
            fi
        done

        # move any leftover packages to upgradepkgs dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$repo/upgradepkgs" ] ; then
              mkdir -p ${edgeRepo}/$repo/upgradepkgs
            fi
            cp ${f} ${edgeRepo}/$repo/upgradepkgs
          fi
        done

      fi
    done
  fi

  if [[ $repo == *redhat_linux_6-yum* ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-redhat-linux-6 --type yum --latest --path $sasRepo
    elif [ -f $cacert ] && [ -f $cert ] ; then
      ./mirrormgr mirror --cert $cert --cacert $cacert --platform x64-redhat-linux-6 --type yum --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    
    for pkgsDir in $(find . -name 'sas-*.rpm*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *redhat*Packages/s ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/basic ]; then
              mkdir -p ${edgeRepo}/$repo/basic
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/analytics ]; then
              mkdir -p ${edgeRepo}/$repo/analytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/astore ]; then
              mkdir -p ${edgeRepo}/$repo/astore
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$repo/gpu ]; then
              mkdir -p ${edgeRepo}/$repo/gpu
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] && [ -f $pkgsDir/sas-txtmineng-*.rpm ]; then
            if [ ! -d ${edgeRepo}/$repo/textanalytics ]; then
              mkdir -p ${edgeRepo}/$repo/textanalytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$repo/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}-*.rpm ] ; then
                packToRemove=$pkgsDir/${i}-*.rpm
                rm $packToRemove
            fi
        done

        # move any leftover packages to upgradepkgs dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$repo/upgradepkgs" ] ; then
              mkdir -p ${edgeRepo}/$repo/upgradepkgs
            fi
            cp ${f} ${edgeRepo}/$repo/upgradepkgs
          fi
        done
        
      fi
    done
  fi

  if [[ $repo == *redhat_linux_7-docker* ]] ; then

    if [ -f $depData ] ; then
      mkdir -p ${edgeRepo}/$repo/docker 
      ./mirrormgr list remote docker tags --deployment-data $depData --latest --path $sasRepo > ${edgeRepo}/$repo/docker/sas_docker_image.txt 
    elif [ -f $cacert ] && [ -f $cert ] ; then
      mkdir -p ${edgeRepo}/$repo/docker
      ./mirrormgr list remote docker tags --cert $cert --cacert $cacert --latest --path $sasRepo > ${edgeRepo}/$repo/docker/sas_docker_image.txt
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    
  fi

done

# Clean up repo content
rm -rf $sasRepo

