#!/bin/bash

# List of packages for deployment types
edgeBasic=('sas-casconnctsub' 'sas-dmcommons' 'sas-dmtkexp' 'sas-embscoreeng' 'sas-espauth' 'sas-espbase' 'sas-espconbase' 'sas-tk' 'sas-tkcas3rdclnt' 'sas-tkcmp' 'sas-tkcpp' 'sas-tkcore' 'sas-tkdq' 'sas-tkesp' 'sas-tkformats' 'sas-tkfnc' 'sas-tkiml' 'sas-tkiog' 'sas-tkiomml' 'sas-tkl4sas' 'sas-tklua' 'sas-tkmtrb' 'sas-tknls' 'sas-tkrabbitmq' 'sas-tksecure' 'sas-tksecuressh' 'sas-tktscore' 'sas-tktslang' 'sas-tktspem')
edgeAnalytics=('sas-espanalytics' 'sas-tkaa' 'sas-tkaacas' 'sas-tketsutil' 'sas-tkregsvm' 'sas-tkstat' 'sas-tksum' 'sas-tktimefilter' )
edgeAstore=('sas-tkair' 'sas-tkbasestat' 'sas-tkcmptrvsn' 'sas-tkdplrning' 'sas-tkhpdmine' 'sas-tkormpgraph' 'sas-tktxtan' 'sas-onnxruntime' 'sas-tkonnx' 'sas-protobuf' )
edgeGpu=('sas-nvidiacuda' 'sas-sasgpudcfg' 'sas-sasgpud' 'sas-openvino')
edgeTextAnalytics=('sas-tktxtan' 'sas-txtmineng' 'sas-tkaudio')
espExtras=('sas-espcondb' 'sas-espconext' 'sas-espcxxdev')
# Repo paths
edgeRepo="./espedge_repos"
sasRepo="$edgeRepo/sas_repos"

# Entitlements
depData=SASViyaV4_*_certs.zip

# Make sure files are in place
if [ ! -f mirrormgr ] ; then
  echo "Could not find mirrormgr at $PWD. Exiting"
  exit
fi
if [ ! -x mirrormgr ] ; then
  echo "mirrormgr must be set to executable. Exiting"
  exit
fi

# Loop through repo list to create mirrors for move packages
for platform in "$@"
do
  if [[ $platform == aarch64-ubuntu-linux-16 ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform aarch64-ubuntu-linux-16 --type apt --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    for pkgsDir in $(find . -name 'sas-*arm64*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *main ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/basic ]; then
              mkdir -p ${edgeRepo}/$platform/basic
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/analytics ]; then
              mkdir -p ${edgeRepo}/$platform/analytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/astore ]; then
              mkdir -p ${edgeRepo}/$platform/astore
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/gpu ]; then
              mkdir -p ${edgeRepo}/$platform/gpu
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] && [ -f $pkgsDir/sas-txtmineng_*.deb ]; then
            if [ ! -d ${edgeRepo}/$platform/textanalytics ]; then
              mkdir -p ${edgeRepo}/$platform/textanalytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}_*.deb ] ; then
                packToRemove=$pkgsDir/${i}_*.deb
                rm $packToRemove
            fi
        done
        # move any leftover packages to espExtras dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$platform/espExtras" ] ; then
              mkdir -p ${edgeRepo}/$platform/espExtras
            fi
            cp ${f} ${edgeRepo}/$platform/espExtras
          fi
        done

      fi
    done
  fi

  if [[ $platform == x64-ubuntu-linux-14 ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-ubuntu-linux-14 --type apt --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    for pkgsDir in $(find . -name 'sas-*amd64*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *main ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/basic ]; then
              mkdir -p ${edgeRepo}/$platform/basic
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/analytics ]; then
              mkdir -p ${edgeRepo}/$platform/analytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/astore ]; then
              mkdir -p ${edgeRepo}/$platform/astore
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] ; then
            if [ ! -d ${edgeRepo}/$platform/gpu ]; then
              mkdir -p ${edgeRepo}/$platform/gpu
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}_*.deb ] && [ -f $pkgsDir/sas-txtmineng_*.deb ]; then
            if [ ! -d ${edgeRepo}/$platform/textanalytics ]; then
              mkdir -p ${edgeRepo}/$platform/textanalytics
            fi
            cp $pkgsDir/${i}_*.deb ${edgeRepo}/$platform/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}_*.deb ] ; then
                packToRemove=$pkgsDir/${i}_*.deb
                rm $packToRemove
            fi
        done

        # move any leftover packages to espExtras dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$platform/espExtras" ] ; then
              mkdir -p ${edgeRepo}/$platform/espExtras
            fi
            cp ${f} ${edgeRepo}/$platform/espExtras
          fi
        done

      fi
    done
  fi


  if [[ $platform == x64-yocto-linux-1 ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-yocto-linux-1 --type yum --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi

    for pkgsDir in $(find . -name 'sas-*yocto*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *yocto*Packages/s ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ ! -d ${edgeRepo}/$platform/basic ]; then
              mkdir -p ${edgeRepo}/$platform/basic
            fi
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/analytics ]; then
              mkdir -p ${edgeRepo}/$platform/analytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/astore ]; then
              mkdir -p ${edgeRepo}/$platform/astore
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/gpu ]; then
              mkdir -p ${edgeRepo}/$platform/gpu
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/gpu
          fi
        done
       
        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] && [ -f $pkgsDir/sas-txtmineng-*.rpm ]; then
            if [ ! -d ${edgeRepo}/$platform/textanalytics ]; then
              mkdir -p ${edgeRepo}/$platform/textanalytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}-*.rpm ] ; then
                packToRemove=$pkgsDir/${i}-*.rpm
                rm $packToRemove
            fi
        done

        # move any leftover packages to espExtras dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$platform/espExtras" ] ; then
              mkdir -p ${edgeRepo}/$platform/espExtras
            fi
            cp ${f} ${edgeRepo}/$platform/espExtras
          fi
        done

      fi
    done
  fi

  if [[ $platform == x64-redhat-linux-6 ]] ; then

    if [ -f $depData ] ; then
      ./mirrormgr mirror --deployment-data $depData --platform x64-redhat-linux-6 --type yum --latest --path $sasRepo
    else
      echo "Could not locate $depData or certificates at $PWD"
    fi
    
    for pkgsDir in $(find . -name 'sas-*.rpm*' -printf '%h\n' | sort -u)
    do
      if [[ $pkgsDir == *redhat*Packages/s ]] ; then
        chmod -R ug+rw $pkgsDir

        # move edgeBasic packages
        for i in ${edgeBasic[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/basic ]; then
              mkdir -p ${edgeRepo}/$platform/basic
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/basic
          fi
        done

        # move edgeAnalytics packages
        for i in ${edgeAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/analytics ]; then
              mkdir -p ${edgeRepo}/$platform/analytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/analytics
          fi
        done

        # move edgeAstore packages
        for i in ${edgeAstore[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/astore ]; then
              mkdir -p ${edgeRepo}/$platform/astore
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/astore
          fi
        done

        # move edgeGpu packages
        for i in ${edgeGpu[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] ; then
            if [ ! -d ${edgeRepo}/$platform/gpu ]; then
              mkdir -p ${edgeRepo}/$platform/gpu
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/gpu
          fi
        done

        # move edgeTextAnalytics packages
        for i in ${edgeTextAnalytics[@]} ; do
          if [ -f $pkgsDir/${i}-*.rpm ] && [ -f $pkgsDir/sas-txtmineng-*.rpm ]; then
            if [ ! -d ${edgeRepo}/$platform/textanalytics ]; then
              mkdir -p ${edgeRepo}/$platform/textanalytics
            fi
            cp $pkgsDir/${i}-*.rpm ${edgeRepo}/$platform/textanalytics
          fi
        done

        combinedList=("${edgeBasic[@]}" "${edgeAnalytics[@]}" "${edgeAstore[@]}" "${edgeGpu[@]}" "${edgeTextAnalytics[@]}")
        #echo $combinedList
        for i in ${combinedList[@]}; do
            if [ -f $pkgsDir/${i}-*.rpm ] ; then
                packToRemove=$pkgsDir/${i}-*.rpm
                rm $packToRemove
            fi
        done

        # move any leftover packages to espExtras dir
        lof=$pkgsDir/*
        for f in $lof ;do
          if [ -f $f ] ; then
            if [ ! -d "${edgeRepo}/$platform/espExtras" ] ; then
              mkdir -p ${edgeRepo}/$platform/espExtras
            fi
            cp ${f} ${edgeRepo}/$platform/espExtras
          fi
        done
        
      fi
    done
  fi

done
# Clean up repo content
rm -rf $sasRepo
